import enum


class Age(enum.Enum):
    """
    Enum to represent the age state
    """
    YOUNG = "YOUNG"
    TEENAGE = "TEENAGE"
    MIDDLEAGE = "MIDDLEAGE"
    ELDERLY = "ELDERLY"
    DECEASED = "DECEASED"
